<?php namespace Terrostar\ChangeNotificationsExtension\Command;

use Anomaly\PagesModule\Page\Form\PageEntryFormBuilder;
use Anomaly\SettingsModule\Setting\Contract\SettingRepositoryInterface;
use Anomaly\UsersModule\Role\Contract\RoleRepositoryInterface;
use Anomaly\UsersModule\User\Contract\UserInterface;
use Illuminate\Contracts\Auth\Guard;
use Illuminate\Notifications\AnonymousNotifiable;
use Terrostar\ChangeNotificationsExtension\Notification\PageHasBeenChanged;

class SendPageChangeNotifications
{

    /**
     * @var PageEntryFormBuilder
     */
    protected $builder;

    /**
     * Create a new SendPageChangeNotifications instance.
     *
     * @param PageEntryFormBuilder $builder
     */
    public function __construct(PageEntryFormBuilder $builder)
    {
        $this->builder = $builder;
    }

    /**
     * @param Guard $auth
     * @param RoleRepositoryInterface $roles
     * @param SettingRepositoryInterface $settings
     */
    public function handle(
        Guard $auth,
        RoleRepositoryInterface $roles,
        SettingRepositoryInterface $settings
    ) {

        /* @var UserInterface $user */
        $user = $auth->user();

        $monitor = (array)$settings->value('terrostar.extension.change_notifications::page_change_monitor', []);
        $notify  = (array)$settings->value('terrostar.extension.change_notifications::page_change_notify', []);

        if (!$user->hasAnyRole($monitor)) {
            return;
        }

        $notified = [];

        foreach ($notify as $role) {
            if ($role = $roles->findBySlug($role)) {

                /* @var UserInterface $user */
                foreach ($role->getUsers() as $user) {

                    if (in_array($user->getId(), $notified)) {
                        continue;
                    }

                    $notified[] = $user->getId();

                    (new AnonymousNotifiable)
                        ->route('mail', $user->getEmail())
                        ->notify(
                            new PageHasBeenChanged($this->builder->getChildFormEntry('page'), $user)
                        );
                }
            }
        }
    }
}
