<?php namespace Terrostar\ChangeNotificationsExtension\Notification;

use Anomaly\PagesModule\Page\Contract\PageInterface;
use Anomaly\Streams\Platform\Notification\Message\MailMessage;
use Anomaly\UsersModule\User\Contract\UserInterface;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Notification;

/**
 * Class PageHasBeenChanged
 *
 * @link   http://pyrocms.com/
 * @author PyroCMS, Inc. <support@pyrocms.com>
 * @author Ryan Thompson <ryan@pyrocms.com>
 */
class PageHasBeenChanged extends Notification implements ShouldQueue
{

    use Queueable;

    /**
     * The modified page.
     *
     * @var PageInterface
     */
    protected $page;

    /**
     * The user making the change.
     *
     * @var UserInterface
     */
    protected $user;

    /**
     * Create a new PageHasBeenChanged instance.
     *
     * @param PageInterface $page
     * @param UserInterface $user
     */
    public function __construct(PageInterface $page, UserInterface $user)
    {
        $this->page = $page;
        $this->user = $user;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @return array
     */
    public function via()
    {
        return ['mail'];
    }

    /**
     * Return the mail message.
     *
     * @return MailMessage
     */
    public function toMail()
    {
        return (new MailMessage())
            ->subject('A page has been modified on ' . config('streams::name'))
            ->greeting(config('streams::name'))
            ->line('A page [' . url($this->page->route('view')) . '] has been modified by: ' . $this->user->getDisplayName())
//            ->action(
//                'View Page',
//                $this->page->route('view')
//            )
            ->action(
                'Edit Page',
                url('admin/pages/edit/' . $this->page->getId())
            );
    }
}
